@@ -333,11 +333,13 @@ ItemManager.method("begin_edit", function()
   // default to current search tags
   if (self.id == null)
   {
-    var search_val = $("#search").val();
-    if (search_val == "")
+    var default_tags = self.manager.query_tags.join(",");
+    if (default_tags == "")
       $("#edit_tags_"+self.id).val("home");
     else
-      $("#edit_tags_"+self.id).val(search_val);
+    {
+      $("#edit_tags_"+self.id).val(default_tags);
+    }
   }
   else
     $("#edit_tags_"+self.id).val(self.tags);
@@ -467,6 +469,8 @@ function ItemCollectionManager()
   self.setup_search();
   self.setup_keyboard_nav();
   self.setup_toolbar();
+
+  self.query_tags = [];
 }
 
 
@@ -559,13 +563,20 @@ ItemCollectionManager.method("setup_history_handling", function()
 
 
 
-ItemCollectionManager.method("add_history_item", function()
+ItemCollectionManager.method("get_current_fragment", function()
 {
-  dhtmlHistory.add(
-    escape(JSON.stringify({
+  return escape(JSON.stringify({
       query:$("#search").val(),
       timestamp:this.view_time
-    })));
+    }));
+});
+
+
+
+
+ItemCollectionManager.method("add_history_item", function()
+{
+  dhtmlHistory.add(this.get_current_fragment());
 });
 
 
@@ -752,6 +763,22 @@ ItemCollectionManager.method("setup_toolbar", function()
     { 
       location.href = "app/quit";
     });
+  $("#btn_copy").click(function()
+    { 
+      var linkurl = $("#linkurl");
+      if (linkurl.hasClass("shown"))
+      {
+        linkurl.removeClass("shown");
+      }
+      else
+      {
+        linkurl.addClass("shown");
+        var linkurl_edit = $("#linkurl_edit").get(0);
+        linkurl_edit.select();
+        linkurl_edit.focus();
+      }
+    });
+  this.install_focus_handlers($("#linkurl_edit"));
 });
 
 
@@ -890,6 +917,8 @@ ItemCollectionManager.method("empty_was_filled", function()
 
 ItemCollectionManager.method("update", function(force)
 {
+  $("#linkurl_edit").val("#"+this.get_current_fragment());
+
   this.fill($("#search").val(), this.view_time, force);
 })
 
@@ -941,6 +970,7 @@ ItemCollectionManager.method("fill", function(query, timestamp, force)
       self.realize_items(items);
 
       fill_subtag_cloud(json);
+      self.query_tags = json.query_tags;
     },
     error: function(req, stat, err)
     {
